Types and traits to enable interoperability between the other Blitz crates without circular or unnecessary dependencies.
Re-exports
pub use node_id::NodeId;pub use keyboard_types;
Modules
- devtools
- Types configure developer inspection and debug tools
- events
- Types to represent UI and DOM events
- navigation
- Abstractions allow embedders to handle link clicks and form submissions
- net
- Abstractions of networking so that custom networking implementations can be provided
- node_id
- Versioned node identifier shared between the Blitz crates.
- platform
- Abstractions of the host platform APIs a guest expects to find: fetching, and per-origin storage.
- profiling
- Process-wide switch for the intrusive performance collectors.
- shell
- Abstraction over windowing / operating system (“shell”) functionality
Structs
- SmolStr
- A
SmolStris a string type that has the following properties: