pub trait ShellProvider:
Send
+ Sync
+ 'static {
// Provided methods
fn request_redraw(&self) { ... }
fn set_cursor(&self, icon: CursorIcon) { ... }
fn set_window_title(&self, title: String) { ... }
fn set_ime_enabled(&self, is_enabled: bool) { ... }
fn set_ime_cursor_area(&self, x: f32, y: f32, width: f32, height: f32) { ... }
fn get_clipboard_text(&self) -> Result<String, ClipboardError> { ... }
fn set_clipboard_text(&self, text: String) -> Result<(), ClipboardError> { ... }
fn open_file_dialog(
&self,
multiple: bool,
filter: Option<FileDialogFilter>,
) -> Vec<PathBuf> { ... }
}Expand description
Abstraction over windowing / operating system (“shell”) functionality that allows a Blitz document to access that functionality without depending on a specific shell environment.