pub trait ShellProvider {
// Provided methods
fn request_redraw(&self) { ... }
fn set_cursor(&self, icon: CursorIcon) { ... }
fn set_window_title(&self, title: String) { ... }
fn get_clipboard_text(&self) -> Result<String, ClipboardError> { ... }
fn set_clipboard_text(&self, text: String) -> Result<(), ClipboardError> { ... }
fn open_file_dialog(
&self,
multiple: bool,
filter: Option<FileDialogFilter>,
) -> Vec<PathBuf> { ... }
}Expand description
Abstraction over windowing / operating system (“shell”) functionality that allows a Blitz document to access that functionality without depending on a specific shell environment.
Provided Methods
fn request_redraw(&self)
fn set_cursor(&self, icon: CursorIcon)
fn set_window_title(&self, title: String)
fn get_clipboard_text(&self) -> Result<String, ClipboardError>
fn set_clipboard_text(&self, text: String) -> Result<(), ClipboardError>
fn open_file_dialog( &self, multiple: bool, filter: Option<FileDialogFilter>, ) -> Vec<PathBuf>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".